@@ -1225,27 +1225,6 @@ void sync_action_list_free(struct sync_action_list **lp)
     *lp = NULL;
 }
 
-/* simple binary search */
-unsigned sync_mailbox_finduid(struct mailbox *mailbox, unsigned uid)
-{
-    unsigned low=1, high=mailbox->i.num_records, mid;
-    struct index_record record;
-
-    while (low <= high) {
-	mid = (high - low)/2 + low;
-	if (mailbox_read_index_record(mailbox, mid, &record))
-	    return 0;
-
-	if (record.uid == uid)
-	    return mid;
-	else if (record.uid > uid)
-	    high = mid - 1;
-	else
-	    low = mid + 1;
-    }
-    return 0;
-}
-
 int addmbox(char *name,
 	    int matchlen __attribute__((unused)),
 	    int maycreate __attribute__((unused)),
