@@ -63,6 +63,7 @@
 #include <sys/types.h>
 #include <sys/un.h>
 #include <unistd.h>
+#include <ctype.h>
 
 #include <sasl/sasl.h>
 #include <sasl/saslutil.h>
@@ -489,13 +490,20 @@ static int tls_init_clientengine(int verifydepth, char *var_tls_cert_file, char
 	printf("TLS engine: cannot seed PRNG\n");
 	return IMTEST_FAIL;
     }
-    
+
+#if (OPENSSL_VERSION_NUMBER >= 0x10100000L)
+    tls_ctx = SSL_CTX_new(TLS_client_method());
+#else
     tls_ctx = SSL_CTX_new(SSLv23_client_method());
+#endif
     if (tls_ctx == NULL) {
 	return IMTEST_FAIL;
     };
-    
-    off |= SSL_OP_ALL;		/* Work around all known bugs */
+
+    off |= SSL_OP_ALL;            /* Work around all known bugs */
+    off |= SSL_OP_NO_SSLv2;       /* Disable insecure SSLv2 */
+    off |= SSL_OP_NO_SSLv3;       /* Disable insecure SSLv3 */
+    off |= SSL_OP_NO_COMPRESSION; /* Disable TLS compression */
     SSL_CTX_set_options(tls_ctx, off);
     SSL_CTX_set_info_callback(tls_ctx, apps_ssl_info_callback);
     
@@ -525,7 +533,7 @@ static int tls_init_clientengine(int verifydepth, char *var_tls_cert_file, char
     
     if (c_cert_file || c_key_file)
 	if (!set_cert_stuff(tls_ctx, c_cert_file, c_key_file)) {
-	    printf("TLS engine: cannot load cert/key data\n");
+            printf("TLS engine: cannot load cert/key data, may be a cert/key mismatch?\n");
 	    return IMTEST_FAIL;
 	}
     SSL_CTX_set_tmp_rsa_callback(tls_ctx, tmp_rsa_cb);
@@ -1227,7 +1235,7 @@ static void interactive(struct protocol_t *protocol, char *filename)
 	
 	/* can't have this and a file for input */
 	sunsock.sun_family = AF_UNIX;
-	strcpy(sunsock.sun_path, output_socket);
+	strlcpy(sunsock.sun_path, output_socket, sizeof(sunsock.sun_path));
 	unlink(output_socket);
 
 	listen_sock = socket(AF_UNIX, SOCK_STREAM, 0);
