@@ -1629,12 +1629,19 @@ static int tls_init_clientengine(struct imclient *imclient,
 	return -1;
     }
 
-    imclient->tls_ctx = SSL_CTX_new(TLSv1_client_method());
+#if (OPENSSL_VERSION_NUMBER >= 0x10100000L)
+    imclient->tls_ctx = SSL_CTX_new(TLS_client_method());
+#else
+    imclient->tls_ctx = SSL_CTX_new(SSLv23_client_method());
+#endif
     if (imclient->tls_ctx == NULL) {
 	return -1;
     };
 
-    off |= SSL_OP_ALL;		/* Work around all known bugs */
+    off |= SSL_OP_ALL;            /* Work around all known bugs */
+    off |= SSL_OP_NO_SSLv2;       /* Disable insecure SSLv2 */
+    off |= SSL_OP_NO_SSLv3;       /* Disable insecure SSLv3 */
+    off |= SSL_OP_NO_COMPRESSION; /* Disable TLS compression */
     SSL_CTX_set_options(imclient->tls_ctx, off);
     
     /* debugging   SSL_CTX_set_info_callback(imclient->tls_ctx, apps_ssl_info_callback); */
@@ -1665,7 +1672,7 @@ static int tls_init_clientengine(struct imclient *imclient,
 
     if (c_cert_file || c_key_file)
 	if (!set_cert_stuff(imclient->tls_ctx, c_cert_file, c_key_file)) {
-	    printf("[ TLS engine: cannot load cert/key data ]\n");
+            printf("[ TLS engine: cannot load cert/key data, may be a cert/key mismatch]\n");
 	    return -1;
 	}
     SSL_CTX_set_tmp_rsa_callback(imclient->tls_ctx, tmp_rsa_cb);
